<?php

namespace Assistant\LoginRedesign;

use _Plugin0\Config;
use _Plugin0\Options;

class Branding {

	/**
	 * @var string
	 */
	private static $brand;

	/**
	 * @var string[]
	 */
	private static $logos = array();

	/**
	 * @var string[]
	 */
	private static $visuals = array();

	/**
	 * @var string[]
	 */
	private static $colors = array();

	public static function init() {
		$brand_params = Config::get( 'branding' );

		if ( ! is_array( $brand_params ) ) {
			return;
		}

		self::$brand = isset( $brand_params['name'] ) ? $brand_params['name'] : '';

		foreach ( $brand_params as $key => $value ) {
			if ( strpos( $key, 'color_' ) !== false ) {
				self::$colors[ str_replace( 'color_', '', $key ) ] = $value;
			}
			if ( strpos( $key, 'logo_' ) !== false ) {
				self::$logos[ str_replace( 'logo_', '', $key ) ] = $value;
			}
			if ( strpos( $key, 'visual_' ) !== false ) {
				self::$visuals[ $key ] = $value;
			}
		}
	}

	public static function get_brand() {
		return self::$brand;
	}

	/**
	 * @param string $variant
	 *
	 * @return string
	 */
	public static function get_logo( $variant = null ) {
		$logos = self::$logos;
		$id = $variant ? $variant : 'default';
		$market = Options::get_market();

		if ( is_array( $logos ) ) {
			if ( array_key_exists( $id . '_' . $market, $logos ) ) {
				return $logos[ $id . '_' . $market ];
			} elseif ( array_key_exists( $id, $logos ) ) {
				return $logos[ $id ];
			}
		}

		return null;
	}

	/**
	 * @param int $id
	 *
	 * @return string
	 */
	public static function get_visual( $id ) {
		$visuals = self::$visuals;

		if ( is_array( $visuals ) && array_key_exists( 'visual_' . $id, $visuals ) ) {
			return $visuals[ 'visual_' . $id ];
		}

		return null;
	}

	/**
	 * Returns the CSS snippet defining all elements with brand colors
	 * (a CSS template is used with placeholders and default values)
	 *
	 * @return string
	 */
	public static function get_color_styles() {
		$inline_styles = '';

		$backgrounds = array();
		$colors = self::$colors;

		$styles_template = ASSISTANT_LOGIN_REDESIGN_DIR . '/css/branding-template.css';
		$images_templates = ASSISTANT_LOGIN_REDESIGN_DIR . '/images/templates/';
		
		// Generate SVGs backgrounds
		foreach ( self::get_backgrounds() as $bg_name => $settings ) {
			$image_file = $images_templates . $bg_name . '.svg';

			if ( is_file( $image_file ) && is_readable( $image_file ) ) {
				$svg = file_get_contents( $image_file );

				if ( is_array( $colors ) && array_key_exists( $settings['color_id'], $colors ) ) {
					$svg = str_replace( 'fill:none', 'fill:' . $colors[ $settings['color_id'] ], $svg );
					$backgrounds[ $bg_name ] = 'data:image/svg+xml;base64,' . base64_encode( $svg );
				} else {
					$backgrounds[ $bg_name ] = $settings['default'];
				}
			}
		}

		// Parse CSS template sheet
		if ( is_file( $styles_template ) && is_readable( $styles_template ) ) {
			$inline_styles = file_get_contents( $styles_template );
		}

		// Render inline styles
		if ( $inline_styles ) {

			// Render simple styles
			if ( is_array( $colors ) ) {
				foreach ( $colors as $color_id => $color_value ) {
					$inline_styles = str_replace( '"{' . $color_id . '}"', $color_value, $inline_styles );
				}
			}

			// Render SVG background styles
			foreach ( $backgrounds as $bg_name => $image ) {
				$inline_styles = str_replace( '"{' . $bg_name . '}"', $image, $inline_styles );
			}
		}

		return $inline_styles;
	}


	/**
	 * Dynamic branded backgrounds
	 *
	 * @return string[]
	 */
	public static function get_backgrounds() {
		return array(
			'weave-light'  => array(
				'color_id' => 'variant3',
				'default'  => plugins_url( 'images/weave-light.svg', ASSISTANT_LOGIN_REDESIGN_FILE )
			),
			'weave-medium' => array(
				'color_id' => 'variant3',
				'default'  => plugins_url( 'images/weave-medium.svg', ASSISTANT_LOGIN_REDESIGN_FILE )
			)
		);
	}

}