<?php
/**
 * Plugin Name:  IONOS Performance
 * Plugin URI:   https://www.ionos.com
 * Description:  IONOS Performance uses a cache to store HTML content generated by WordPress temporarily. You can use this cache to improve your website’s performance without the need for cumbersome configuration simply by activating this plugin.
 * Version:      1.0.1
 * License:      GPLv2 or later
 * Author:       IONOS
 * Author URI:   https://www.ionos.com
 * Text Domain:  ionos-performance
 */

/*
Copyright 2022 IONOS
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Online: http://www.gnu.org/licenses/gpl.txt
*/

namespace Ionos\Performance;

use Ionos\Performance\Config;
use Ionos\Performance\Options;
use Ionos\Performance\Updater;
use Ionos\Performance\Plugin;
use Ionos\Performance\Menu;
use Ionos\Performance\Warning;
use Ionos\Performance\Manager;

define( 'IONOS_PERFORMANCE_FILE', __FILE__ );
define( 'IONOS_PERFORMANCE_DIR', dirname( __FILE__ ) );
define( 'IONOS_PERFORMANCE_BASE', plugin_basename( __FILE__ ) );
define( 'IONOS_PERFORMANCE_CACHE_DIR', WP_CONTENT_DIR . '/cache/ionos-performance' );

/**
 * Init plugin.
 *
 * @return void
 */
function init() {
	require_once 'inc/lib/options.php';
	Options::set_tenant_and_plugin_name( 'ionos', 'performance' );
	require_once 'inc/lib/data-providers/cloud.php';
	require_once 'inc/lib/config.php';
	require_once 'inc/lib/updater.php';
	require_once 'inc/lib/features/disable-plugins/class-manager.php';

	require_once 'inc/class-helper.php';
	require_once 'inc/class-caching.php';
	require_once 'inc/class-plugin.php';

	new Updater();
	new Warning( 'ionos-performance' );

	require_once 'inc/class-manager.php';
	if ( ! Config::get( 'features.enabled' ) || Manager::get_option( 'caching_enabled' ) == 0 ) {
		if ( true === Plugin::is_htaccess_modified() ) {
			Caching::clear_cache();
			Plugin::remove_htaccess_snippet();
		}
	}

	if ( false === Plugin::is_htaccess_modified() && 1 == Manager::get_option( 'caching_enabled' ) ) {
		Plugin::add_htaccess_snippet();
	}
	if ( ! Config::get( 'features.enabled' ) ) {
		return null;
	}

	require_once 'inc/lib/features/menu/class-menu.php';
	add_action(
		'admin_menu',
		function() {
			Menu::add_submenu_page(
				'Caching',
				'Caching',
				'manage_options',
				'ionos_performance',
				array( '\Ionos\Performance\Manager', 'options_page' ),
				null
			);
		}
	);

	new Caching();
	new Manager();
}

\add_action( 'plugins_loaded', 'Ionos\Performance\init' );

function activate() {
	require_once 'inc/class-plugin.php';
	Plugin::add_htaccess_snippet();
}
register_activation_hook( __FILE__, 'Ionos\Performance\activate' );

function deactivate() {
	require_once 'inc/class-plugin.php';
	Plugin::remove_htaccess_snippet();
}
register_deactivation_hook( __FILE__, 'Ionos\Performance\deactivate' );

/**
 * Plugin translation.
 *
 * @return void
 */
function load_textdomain() {
	\load_plugin_textdomain(
		'ionos-performance',
		false,
		\dirname( \plugin_basename( __FILE__ ) ) . '/languages/'
	);
}
\add_action( 'init', 'Ionos\Performance\load_textdomain' );