<?php
/**
 * The Google Maps field.
 *
 * @package Meta Box
 */

/**
 * Map field class.
 */
class RWMB_Map_Field extends RWMB_Field {
	/**
	 * Enqueue scripts and styles.
	 */
	public static function admin_enqueue_scripts() {
		wp_enqueue_style( 'rwmb-map', RWMB_CSS_URL . 'map.css', array(), RWMB_VER );
	}

	/**
	 * Get field HTML.
	 *
	 * @param mixed $meta  Meta value.
	 * @param array $field Field parameters.
	 *
	 * @return string
	 */
	public static function html( $meta, $field ) {
		$address = is_array( $field['address_field'] ) ? implode( ',', $field['address_field'] ) : $field['address_field'];
		$html    = sprintf(
			'<div class="rwmb-map-field" data-address-field="%s">',
			esc_attr( $address )
		);


		$stp5_mapty = PFSAIssetControl('stp5_mapty','',1);
		$wemap_here_appid = $wemap_here_appcode = $we_special_key = $setup5_typs = $wemap_country = $mapboxfull_url = $yandexfull_url = '';
		$setup5_typs = PFSAIssetControl('setup5_typs','','geocode');
		$wemap_country = PFSAIssetControl('wemap_country');


		switch ($stp5_mapty) {
			case 1:
				$we_special_key = PFSAIssetControl('setup5_map_key');
				break;

			case 3:
				$we_special_key = PFSAIssetControl('stp5_mapboxpt');
				break;

			case 5:
				$wemap_here_appid = PFSAIssetControl('wemap_here_appid');
				$wemap_here_appcode = PFSAIssetControl('wemap_here_appcode');
				break;

			case 6:
				$we_special_key = PFSAIssetControl('wemap_bingmap_api_key');
				break;

			case 4:
				$we_special_key = PFSAIssetControl('wemap_yandexmap_api_key');
				$wemap_langy = PFSAIssetControl('wemap_langy');
				break;
		}

		$wemap_geoctype = PFSAIssetControl('wemap_geoctype');

		if (!empty($meta)) {
			$defloca = explode(",",esc_attr($meta));
		}else{
			$defloca = explode(",",esc_attr($field['std']));
		}


		$html .= '<a class="button" id="pf_search_geolocateme" data-istatus="false" title="'.esc_html__('Locate me!','pointfindercoreelements').'">
		<i class="far fa-compass pf-search-locatemebut"></i>
		<div class="pf-search-locatemebutloading"></div>
		</a>';
		$html .=
			'<div id="pfupload_map" style="width: 100%;height: 300px;border:0" 
    		data-lat="'.$defloca[0].'" 
    		data-lng="'.$defloca[1].'" 
    		data-zoom="14" 
    		data-zoommx="14" 
    		data-mtype="'.$stp5_mapty.'" 
    		data-key="'.$we_special_key.'" 
    		data-hereappid="'.$wemap_here_appid.'" 
			data-hereappcode="'.$wemap_here_appcode.'" 
			data-geoctype="'.$wemap_geoctype.'" 
			data-setup5typs="'.$setup5_typs.'" 
			data-wemapcountry="'.$wemap_country.'"
			data-pf-istatus="false" class="rwmb-map-canvas" data-default-loc="'.esc_attr( $field['std'] ).'" data-region="'.esc_attr( $field['region'] ).'" data-text1="'.esc_html__( "No results found for {{query}}", "pointfindercoreelements" ).'"></div>';




		$html .= sprintf(
			"<input type='text' name='%s' class='rwmb-map-coordinate' value='%s' style='%s'>",
			esc_attr( $field['field_name'] ),
			esc_attr( $meta ),
			'width:50%'
		);
		$html .= '';
		$html .= '<input name="findaddress" type="button" class="button button-primary button-large rwmb-map-coordinate-find" id="rwmb-map-coordinate-find" value="'.esc_html__( "Find Coordinate", "pointfindercoreelements" ).'"></div>';

		return $html;
	}

	/**
	 * Normalize parameters for field.
	 *
	 * @param array $field Field parameters.
	 *
	 * @return array
	 */
	public static function normalize( $field ) {
		$field = parent::normalize( $field );
		$field = wp_parse_args(
			$field,
			array(
				'std'           => '',
				'address_field' => '',
				'language'      => '',
				'region'        => '',
			)
		);

		return $field;
	}

	/**
	 * Get the field value.
	 * The difference between this function and 'meta' function is 'meta' function always returns the escaped value
	 * of the field saved in the database, while this function returns more meaningful value of the field.
	 *
	 * @param  array    $field   Field parameters.
	 * @param  array    $args    Not used for this field.
	 * @param  int|null $post_id Post ID. null for current post. Optional.
	 *
	 * @return mixed Array(latitude, longitude, zoom)
	 */
	public static function get_value( $field, $args = array(), $post_id = null ) {
		$value                               = parent::get_value( $field, $args, $post_id );
		list( $latitude, $longitude, $zoom ) = explode( ',', $value . ',,' );
		return compact( 'latitude', 'longitude', 'zoom' );
	}

	/**
	 * Output the field value.
	 * Display Google maps.
	 *
	 * @param  array    $field   Field parameters.
	 * @param  array    $args    Additional arguments for the map.
	 * @param  int|null $post_id Post ID. null for current post. Optional.
	 *
	 * @return string HTML output of the field
	 */
	public static function the_value( $field, $args = array(), $post_id = null ) {
		$value = parent::get_value( $field, $args, $post_id );
		$args  = wp_parse_args(
			$args,
			array(
				'api_key' => isset( $field['api_key'] ) ? $field['api_key'] : '',
			)
		);
		return self::render_map( $value, $args );
	}

	/**
	 * Render a map in the frontend.
	 *
	 * @param array $location The [latitude, longitude[, zoom]] location.
	 * @param array $args     Additional arguments for the map.
	 *
	 * @return string
	 */
	public static function render_map( $location, $args = array() ) {
		list( $latitude, $longitude, $zoom ) = explode( ',', $location . ',,' );
		if ( ! $latitude || ! $longitude ) {
			return '';
		}

		$args = wp_parse_args(
			$args,
			array(
				'latitude'     => $latitude,
				'longitude'    => $longitude,
				'width'        => '100%',
				'height'       => '480px',
				'marker'       => true, // Display marker?
				'marker_title' => '', // Marker title, when hover.
				'info_window'  => '', // Content of info window (when click on marker). HTML allowed.
				'js_options'   => array(),
				'zoom'         => $zoom,

			)
		);

		$google_maps_url = add_query_arg( 'key', $args['api_key'], 'https://maps.google.com/maps/api/js' );

		/*
		 * Allows developers load more libraries via a filter.
		 * @link https://developers.google.com/maps/documentation/javascript/libraries
		 */
		$google_maps_url = apply_filters( 'rwmb_google_maps_url', $google_maps_url );
		wp_register_script( 'google-maps', esc_url_raw( $google_maps_url ), array(), RWMB_VER, true );
		wp_enqueue_script( 'rwmb-map-frontend', RWMB_JS_URL . 'map-frontend.js', array( 'google-maps', 'jquery' ), RWMB_VER, true );

		/*
		 * Google Maps options.
		 * Option name is the same as specified in Google Maps documentation.
		 * This array will be convert to Javascript Object and pass as map options.
		 * @link https://developers.google.com/maps/documentation/javascript/reference
		 */
		$args['js_options'] = wp_parse_args(
			$args['js_options'],
			array(
				// Default to 'zoom' level set in admin, but can be overwritten.
				'zoom'      => $args['zoom'],

				// Map type, see https://developers.google.com/maps/documentation/javascript/reference#MapTypeId.
				'mapTypeId' => 'ROADMAP',

				// Open Info Window
				'openInfoWindow' => false,
			)
		);

		$output = sprintf(
			'<div class="rwmb-map-canvas" data-map_options="%s" style="width:%s;height:%s"></div>',
			esc_attr( wp_json_encode( $args ) ),
			esc_attr( $args['width'] ),
			esc_attr( $args['height'] )
		);
		return $output;
	}
}
